@@ -171,6 +171,8 @@ sub _authorization_only {
     };
 
     my $res = $self->_send_request($config,$content);
+    $self->error_message( $res->{'desc'} );
+    $self->result_code( $res->{'error_code'} );
     $self->is_success( defined $res->{'result'} && $res->{'result'} =~ /^9|11$/ ? 1 : 0 );
     $self->order_number( $res->{'x_document'} // $res->{'x_auth_id'} ); # sale vs auth
     $res;
@@ -187,6 +189,8 @@ sub _post_authorization{
     };
 
     my $res = $self->_send_request($config,$content);
+    $self->error_message( $res->{'desc'} );
+    $self->result_code( $res->{'error_code'} );
     $self->is_success( defined $res->{'result'} && $res->{'result'} =~ /^9|11$/ ? 1 : 0 );
     $self->order_number( $res->{'x_document'} // $res->{'x_auth_id'} ); # sale vs auth
     $res;
@@ -203,6 +207,8 @@ sub _tokenize {
     };
 
     my $res = $self->_send_request($config,$content);
+    $self->error_message( $res->{'desc'} );
+    $self->result_code( $res->{'error_code'} );
     $self->is_success( $res->{'cc_token'} ? 1 : 0 );
     $self->card_token( $res->{'cc_token'} );
     $res;
@@ -219,6 +225,8 @@ sub _credit {
     };
 
     my $res = $self->_send_request($config,$content);
+    $self->error_message( $res->{'desc'} );
+    $self->result_code( $res->{'error_code'} );
     $self->is_success( defined $res->{'result'} && $res->{'result'} eq '1' ? 1 : 0 );
     $self->order_number( $res->{'x_document'} );
     $res;
@@ -239,6 +247,8 @@ sub _paystatus {
     local $content->{'password'} = $content->{'reports_key'};
 
     my $res = $self->_send_request($config,$content);
+    $self->error_message( $res->{'desc'} );
+    $self->result_code( $res->{'error_code'} );
     $self->is_success( defined $res->{'result'} ); # any result is a positive think for a query call
     $self->order_number( $res->{'x_document'} );
     $res;
@@ -259,6 +269,8 @@ sub _refundstatus {
     local $content->{'password'} = $content->{'reports_key'};
 
     my $res = $self->_send_request($config,$content);
+    $self->error_message( $res->{'desc'} );
+    $self->result_code( $res->{'error_code'} );
     $self->is_success( defined $res->{'result'} ); # any result is a positive think for a query call
     $self->order_number( $res->{'x_document'} );
     $res;
@@ -439,7 +451,7 @@ Business::OnlinePayment::DLocal - Business::OnlinePayment::DLocal - DLocal (astr
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 METHODS
 
